

| **Docs** | [![Documentation Status](https://readthedocs.org/projects/qc2champ/badge/?version=latest)](https://qc2champ.readthedocs.io/en/latest/?badge=latest) |
| --- | :--- |
| **CI/CD** | [![Create Python package](https://github.com/neelravi/qc2champ/actions/workflows/python-package.yml/badge.svg)](https://github.com/neelravi/qc2champ/actions/workflows/python-package.yml) [![Publish Python Package](https://github.com/neelravi/qc2champ/actions/workflows/python-publish.yml/badge.svg)](https://github.com/neelravi/qc2champ/actions/workflows/python-publish.yml) |
| **Status** | ![Github Issues](https://img.shields.io/github/issues/neelravi/qc2champ) ![Github Pull Requests](https://img.shields.io/github/issues-pr/neelravi/qc2champ) ![Github Last Commit](https://img.shields.io/github/last-commit/neelravi/qc2champ) ![Github Commit Status](https://img.shields.io/github/commit-status/neelravi/qc2champ/main/17440cdde4fea69ee3136256e82fabf94304c967) ![Commit Activity](https://img.shields.io/github/commit-activity/w/neelravi/qc2champ) |
| **Info**   | ![Last release tag](https://img.shields.io/github/v/tag/neelravi/qc2champ) ![Github forks](https://img.shields.io/github/forks/neelravi/qc2champ) ![Github stars](https://img.shields.io/github/stars/neelravi/qc2champ)  ![Main Language](https://img.shields.io/github/languages/top/neelravi/qc2champ)  ![Repo Size](https://img.shields.io/github/repo-size/neelravi/qc2champ) ![Code Size](https://img.shields.io/github/languages/code-size/neelravi/qc2champ)|
| **License** | ![Github license](https://img.shields.io/github/license/neelravi/qc2champ)|